@@ -41,11 +41,9 @@ struct _GsScreenshotImagePrivate
 	GtkWidget	*image2;
 	GtkWidget	*label_error;
 	SoupSession	*session;
-	SoupMessage	*message;
 	gchar		*cachedir;
 	gchar		*filename;
 	const gchar	*current_image;
-	gboolean	 use_desktop_background;
 	guint		 width;
 	guint		 height;
 	gint		 scale;
@@ -114,18 +112,14 @@ gs_screenshot_image_get_desktop_pixbuf (GsScreenshotImage *ssimg)
  * gs_screenshot_image_use_desktop_background:
  **/
 static gboolean
-gs_screenshot_image_use_desktop_background (GsScreenshotImage *ssimg, GdkPixbuf *pixbuf)
+gs_screenshot_image_use_desktop_background (GdkPixbuf *pixbuf)
 {
-	GsScreenshotImagePrivate *priv = gs_screenshot_image_get_instance_private (ssimg);
 	AsImage *im;
 	gboolean ret;
 
 	/* nothing to show, means no background mode */
 	if (pixbuf == NULL)
 		return FALSE;
-	/* background mode explicitly disabled */
-	if (!priv->use_desktop_background)
-		return FALSE;
 
 	/* use a temp AsImage */
 	im = as_image_new ();
@@ -153,11 +147,11 @@ as_screenshot_show_image (GsScreenshotImage *ssimg)
 	} else {
 		/* this is always going to have alpha */
 		pixbuf = gdk_pixbuf_new_from_file_at_scale (priv->filename,
-							    priv->width * priv->scale,
-							    priv->height * priv->scale,
+							    priv->width,
+							    priv->height,
 							    FALSE, NULL);
 		if (pixbuf != NULL) {
-			if (gs_screenshot_image_use_desktop_background (ssimg, pixbuf)) {
+			if (gs_screenshot_image_use_desktop_background (pixbuf)) {
 				pixbuf_bg = gs_screenshot_image_get_desktop_pixbuf (ssimg);
 				if (pixbuf_bg == NULL) {
 					pixbuf_bg = g_object_ref (pixbuf);
@@ -198,6 +192,46 @@ as_screenshot_show_image (GsScreenshotImage *ssimg)
 	gtk_widget_show (GTK_WIDGET (ssimg));
 }
 
+/**
+ * gs_screenshot_image_show_blurred:
+ **/
+static void
+gs_screenshot_image_show_blurred (GsScreenshotImage *ssimg,
+				  const gchar *filename_thumb)
+{
+	AsImage *im;
+	GdkPixbuf *pb = NULL;
+	GsScreenshotImagePrivate *priv;
+	gboolean ret;
+
+	priv = gs_screenshot_image_get_instance_private (ssimg);
+
+	/* create an helper which can do the blurring for us */
+	im = as_image_new ();
+	ret = as_image_load_filename (im, filename_thumb, NULL);
+	if (!ret)
+		goto out;
+	pb = as_image_save_pixbuf (im,
+				   priv->width * priv->scale,
+				   priv->height * priv->scale,
+				   AS_IMAGE_SAVE_FLAG_BLUR);
+	if (pb == NULL)
+		goto out;
+
+	if (g_strcmp0 (priv->current_image, "image1") == 0) {
+		gs_image_set_from_pixbuf_with_scale (GTK_IMAGE (priv->image1),
+						     pb, priv->scale);
+	} else {
+		gs_image_set_from_pixbuf_with_scale (GTK_IMAGE (priv->image2),
+						     pb, priv->scale);
+	}
+out:
+	if (im != NULL)
+		g_object_unref (im);
+	if (pb != NULL)
+		g_object_unref (pb);
+}
+
 /**
  * gs_screenshot_image_complete_cb:
  **/
@@ -206,18 +240,14 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 				 SoupMessage *msg,
 				 gpointer user_data)
 {
-	GsScreenshotImage *ssimg = GS_SCREENSHOT_IMAGE (user_data);
-	GsScreenshotImagePrivate *priv = gs_screenshot_image_get_instance_private (ssimg);
 	AsImage *im = NULL;
+	GsScreenshotImagePrivate *priv;
+	GsScreenshotImage *ssimg = GS_SCREENSHOT_IMAGE (user_data);
 	GError *error = NULL;
 	GdkPixbuf *pixbuf = NULL;
 	GInputStream *stream = NULL;
 	gboolean ret;
 
-	/* return immediately if the message was cancelled or if we're in destruction */
-	if (msg->status_code == SOUP_STATUS_CANCELLED || priv->session == NULL)
-		goto out;
-
 	if (msg->status_code != SOUP_STATUS_OK) {
 		/* TRANSLATORS: this is when we try to download a screenshot and
 		 * we get back 404 */
@@ -226,6 +256,8 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 		goto out;
 	}
 
+	priv = gs_screenshot_image_get_instance_private (ssimg);
+
 	/* create a buffer with the data */
 	stream = g_memory_input_stream_new_from_data (msg->response_body->data,
 						      msg->response_body->length,
@@ -243,8 +275,8 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 
 	/* is image size destination size unknown or exactly the correct size */
 	if (priv->width == G_MAXUINT || priv->height == G_MAXUINT ||
-	    (priv->width * priv->scale == (guint) gdk_pixbuf_get_width (pixbuf) &&
-	     priv->height * priv->scale == (guint) gdk_pixbuf_get_height (pixbuf))) {
+	    (priv->width == (guint) gdk_pixbuf_get_width (pixbuf) &&
+	     priv->height == (guint) gdk_pixbuf_get_height (pixbuf))) {
 		ret = g_file_set_contents (priv->filename,
 					   msg->response_body->data,
 					   msg->response_body->length,
@@ -260,8 +292,7 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 		im = as_image_new ();
 		as_image_set_pixbuf (im, pixbuf);
 		ret = as_image_save_filename (im, priv->filename,
-					      priv->width * priv->scale,
-					      priv->height * priv->scale,
+					      priv->width, priv->height,
 					      AS_IMAGE_SAVE_FLAG_PAD_16_9, &error);
 		if (!ret) {
 			gs_screenshot_image_set_error (ssimg, error->message);
@@ -334,18 +365,6 @@ gs_screenshot_image_set_size (GsScreenshotImage *ssimg,
 	gtk_widget_set_size_request (priv->stack, width, height);
 }
 
-/**
- * gs_screenshot_image_set_use_desktop_background:
- **/
-void
-gs_screenshot_image_set_use_desktop_background (GsScreenshotImage *ssimg,
-                                                gboolean use_desktop_background)
-{
-	GsScreenshotImagePrivate *priv = gs_screenshot_image_get_instance_private (ssimg);
-	g_return_if_fail (GS_IS_SCREENSHOT_IMAGE (ssimg));
-	priv->use_desktop_background = use_desktop_background;
-}
-
 /**
  * gs_screenshot_image_load_async:
  **/
@@ -355,10 +374,12 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 {
 	AsImage *im = NULL;
 	GsScreenshotImagePrivate *priv;
+	SoupMessage *msg = NULL;
 	SoupURI *base_uri = NULL;
 	const gchar *url;
 	gchar *basename = NULL;
 	gchar *cachedir = NULL;
+	gchar *cachedir2 = NULL;
 	gchar *sizedir = NULL;
 	gint rc;
 
@@ -370,15 +391,18 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	g_return_if_fail (priv->width != 0);
 	g_return_if_fail (priv->height != 0);
 
-	/* load an image according to the scale factor */
-	priv->scale = gtk_widget_get_scale_factor (GTK_WIDGET (ssimg));
-	im = as_screenshot_get_image (priv->screenshot,
-				      priv->width * priv->scale,
-				      priv->height * priv->scale);
+	/* load the HiDPI image if it exists */
+	priv->scale = 1;
+	if (gtk_widget_get_scale_factor (GTK_WIDGET (ssimg)) > 1) {
+		im = as_screenshot_get_image (priv->screenshot,
+					      priv->width * 2,
+					      priv->height * 2);
+		if (im != NULL)
+			priv->scale *= 2;
+	}
 
-	/* if we've failed to load a HiDPI image, fallback to LoDPI */
-	if (im == NULL && priv->scale > 1) {
-		priv->scale = 1;
+	/* fallback to LoDPI if it exists */
+	if (im == NULL) {
 		im = as_screenshot_get_image (priv->screenshot,
 					      priv->width,
 					      priv->height);
@@ -394,7 +418,7 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	if (priv->width == G_MAXUINT || priv->height == G_MAXUINT) {
 		sizedir = g_strdup ("unknown");
 	} else {
-		sizedir = g_strdup_printf ("%ux%u", priv->width * priv->scale, priv->height * priv->scale);
+		sizedir = g_strdup_printf ("%ux%u", priv->width, priv->height);
 	}
 	cachedir = g_build_filename (priv->cachedir,
 				     "gnome-software",
@@ -416,40 +440,44 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 		goto out;
 	}
 
+	/* can we load a blurred smaller version of this straight away */
+	if (priv->width > AS_IMAGE_THUMBNAIL_WIDTH &&
+	    priv->height > AS_IMAGE_THUMBNAIL_HEIGHT) {
+		cachedir2 = g_build_filename (priv->cachedir,
+					      "gnome-software",
+					      "screenshots",
+					      "112x63",
+					      basename,
+					      NULL);
+		if (g_file_test (cachedir2, G_FILE_TEST_EXISTS))
+			gs_screenshot_image_show_blurred (ssimg, cachedir2);
+	}
+
 	/* download file */
 	g_debug ("downloading %s to %s", url, priv->filename);
 	base_uri = soup_uri_new (url);
-	if (base_uri == NULL || !SOUP_URI_VALID_FOR_HTTP (base_uri)) {
+	if (base_uri == NULL) {
 		/* TRANSLATORS: this is when we try to download a screenshot
 		 * that was not a valid URL */
 		gs_screenshot_image_set_error (ssimg, _("Screenshot not valid"));
 		goto out;
 	}
-
-	/* cancel any previous messages */
-	if (priv->message != NULL) {
-		soup_session_cancel_message (priv->session,
-		                             priv->message,
-		                             SOUP_STATUS_CANCELLED);
-		g_clear_object (&priv->message);
-	}
-
-	priv->message = soup_message_new_from_uri (SOUP_METHOD_GET, base_uri);
-	if (priv->message == NULL) {
+	msg = soup_message_new_from_uri (SOUP_METHOD_GET, base_uri);
+	if (msg == NULL) {
 		/* TRANSLATORS: this is when networking is not available */
 		gs_screenshot_image_set_error (ssimg, _("Screenshot not available"));
 		goto out;
 	}
 
 	/* send async */
-	soup_session_queue_message (priv->session,
-				    g_object_ref (priv->message) /* transfer full */,
+	soup_session_queue_message (priv->session, msg,
 				    gs_screenshot_image_complete_cb,
 				    g_object_ref (ssimg));
 out:
 	g_free (basename);
 	g_free (sizedir);
 	g_free (cachedir);
+	g_free (cachedir2);
 	if (base_uri != NULL)
 		soup_uri_free (base_uri);
 }
@@ -465,12 +493,6 @@ gs_screenshot_image_destroy (GtkWidget *widget)
 
 	priv = gs_screenshot_image_get_instance_private (ssimg);
 
-	if (priv->message != NULL) {
-		soup_session_cancel_message (priv->session,
-		                             priv->message,
-		                             SOUP_STATUS_CANCELLED);
-		g_clear_object (&priv->message);
-	}
 	g_clear_object (&priv->screenshot);
 	g_free (priv->cachedir);
 	priv->cachedir = NULL;
@@ -490,7 +512,6 @@ gs_screenshot_image_init (GsScreenshotImage *ssimg)
 	AtkObject *accessible;
 
 	ssimg->priv = gs_screenshot_image_get_instance_private (ssimg);
-	ssimg->priv->use_desktop_background = TRUE;
 
 	gtk_widget_set_has_window (GTK_WIDGET (ssimg), FALSE);
 	gtk_widget_init_template (GTK_WIDGET (ssimg));
