@@ -33,7 +33,6 @@
 #include "gs-app-addon-row.h"
 #include "gs-history-dialog.h"
 #include "gs-screenshot-image.h"
-#include "gs-progress-button.h"
 #include "gs-star-widget.h"
 
 static void	gs_shell_details_finalize	(GObject	*object);
@@ -239,16 +238,6 @@ gs_shell_details_switch_to (GsShellDetails *shell_details)
 		}
 	}
 
-	/* do a fill bar for the current progress */
-	switch (gs_app_get_state (priv->app)) {
-	case AS_APP_STATE_INSTALLING:
-		gs_progress_button_set_show_progress (GS_PROGRESS_BUTTON (priv->button_install), TRUE);
-		break;
-	default:
-		gs_progress_button_set_show_progress (GS_PROGRESS_BUTTON (priv->button_install), FALSE);
-		break;
-	}
-
 	/* spinner */
 	if (kind == GS_APP_KIND_SYSTEM) {
 		gtk_widget_set_visible (priv->spinner_install_remove, FALSE);
@@ -262,10 +251,10 @@ gs_shell_details_switch_to (GsShellDetails *shell_details)
 		case AS_APP_STATE_UPDATABLE:
 		case AS_APP_STATE_UNAVAILABLE:
 		case AS_APP_STATE_AVAILABLE_LOCAL:
-		case AS_APP_STATE_INSTALLING:
 			gtk_widget_set_visible (priv->spinner_install_remove, FALSE);
 			gtk_spinner_stop (GTK_SPINNER (priv->spinner_install_remove));
 			break;
+		case AS_APP_STATE_INSTALLING:
 		case AS_APP_STATE_REMOVING:
 			gtk_spinner_start (GTK_SPINNER (priv->spinner_install_remove));
 			gtk_widget_set_visible (priv->spinner_install_remove, TRUE);
@@ -283,27 +272,6 @@ gs_shell_details_switch_to (GsShellDetails *shell_details)
 	gs_grab_focus_when_mapped (priv->scrolledwindow_details);
 }
 
-static gboolean
-gs_shell_details_refresh_progress_idle (gpointer user_data)
-{
-	GsShellDetails *shell_details = GS_SHELL_DETAILS (user_data);
-	GsShellDetailsPrivate *priv = shell_details->priv;
-
-	gs_progress_button_set_progress (GS_PROGRESS_BUTTON (priv->button_install),
-	                                 gs_app_get_progress (priv->app));
-
-	g_object_unref (shell_details);
-	return G_SOURCE_REMOVE;
-}
-
-static void
-gs_shell_details_progress_changed_cb (GsApp *app,
-                                      GParamSpec *pspec,
-                                      GsShellDetails *shell_details)
-{
-	g_idle_add (gs_shell_details_refresh_progress_idle, g_object_ref (shell_details));
-}
-
 static gboolean
 gs_shell_details_switch_to_idle (gpointer user_data)
 {
@@ -388,9 +356,8 @@ gs_shell_details_refresh_screenshots (GsShellDetails *shell_details)
 							  g_get_user_cache_dir ());
 			gs_screenshot_image_set_screenshot (GS_SCREENSHOT_IMAGE (ssimg), ss);
 			gs_screenshot_image_set_size (GS_SCREENSHOT_IMAGE (ssimg),
-						      640,
-						      48);
-			gs_screenshot_image_set_use_desktop_background (GS_SCREENSHOT_IMAGE (ssimg), FALSE);
+						      G_MAXUINT,
+						      G_MAXUINT);
 			gs_screenshot_image_load_async (GS_SCREENSHOT_IMAGE (ssimg), NULL);
 			gtk_box_pack_start (GTK_BOX (priv->box_details_screenshot_main), ssimg, FALSE, FALSE, 0);
 			gtk_widget_set_visible (ssimg, TRUE);
@@ -741,11 +708,6 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 		break;
 	}
 
-	/* don't show the launch button if the app doesn't have a desktop ID */
-	tmp = gs_app_get_id (priv->app);
-	if (tmp == NULL)
-		gtk_widget_set_visible (priv->button_details_launch, FALSE);
-
 	/* make history button insensitive if there is none */
 	history = gs_app_get_history (priv->app);
 	switch (gs_app_get_id_kind (priv->app)) {
@@ -944,25 +906,8 @@ gs_shell_details_filename_to_app_cb (GObject *source,
 							    res,
 							    &error);
 	if (priv->app == NULL) {
-		GtkWidget *dialog;
-
-		dialog = gtk_message_dialog_new (gs_shell_get_window (priv->shell),
-		                                 GTK_DIALOG_MODAL |
-		                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-		                                 GTK_MESSAGE_ERROR,
-		                                 GTK_BUTTONS_CLOSE,
-		                                 _("Sorry, this did not work"));
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-		                                          "%s", error->message);
-		g_signal_connect (dialog, "response",
-		                  G_CALLBACK (gtk_widget_destroy), NULL);
-		gtk_window_present (GTK_WINDOW (dialog));
-
 		g_warning ("failed to convert to GsApp: %s", error->message);
 		g_error_free (error);
-
-		/* Switch away from the details view that failed to load */
-		gs_shell_set_mode (priv->shell, GS_SHELL_MODE_OVERVIEW);
 		return;
 	}
 
@@ -1065,9 +1010,6 @@ gs_shell_details_set_app (GsShellDetails *shell_details, GsApp *app)
 	g_signal_connect_object (priv->app, "notify::licence",
 				 G_CALLBACK (gs_shell_details_notify_state_changed_cb),
 				 shell_details, 0);
-	g_signal_connect_object (priv->app, "notify::progress",
-				 G_CALLBACK (gs_shell_details_progress_changed_cb),
-				 shell_details, 0);
 	gs_shell_details_load (shell_details);
 
 	/* change widgets */
@@ -1309,16 +1251,12 @@ gs_shell_details_app_launch_button_cb (GtkWidget *widget, GsShellDetails *shell_
 	const gchar *desktop_id;
 
 	desktop_id = gs_app_get_id (shell_details->priv->app);
-	if (desktop_id == NULL) {
-		g_warning ("no such desktop file: %s", desktop_id);
-		return;
-	}
+	display = gdk_display_get_default ();
 	appinfo = G_APP_INFO (g_desktop_app_info_new (desktop_id));
 	if (appinfo == NULL) {
 		g_warning ("no such desktop file: %s", desktop_id);
 		return;
 	}
-	display = gdk_display_get_default ();
 	context = G_APP_LAUNCH_CONTEXT (gdk_display_get_app_launch_context (display));
 	if (!g_app_info_launch (appinfo, NULL, context, &error)) {
 		g_warning ("launching %s failed: %s", desktop_id, error->message);
@@ -1516,8 +1454,7 @@ gs_shell_details_init (GsShellDetails *shell_details)
 	/* setup networking */
 	priv->session = soup_session_sync_new_with_options (SOUP_SESSION_USER_AGENT,
 							    "gnome-software",
-							    SOUP_SESSION_TIMEOUT, 60,
-							    SOUP_SESSION_IDLE_TIMEOUT, 60,
+							    SOUP_SESSION_TIMEOUT, 5000,
 							    NULL);
 	if (priv->session != NULL) {
 		soup_session_add_feature_by_type (priv->session,
