@@ -61,15 +61,16 @@ save_back_entry (GsUpdateDialog *dialog)
 {
 	GsUpdateDialogPrivate *priv = gs_update_dialog_get_instance_private (dialog);
 	BackEntry *entry;
+	GtkWidget *focus;
 
 	entry = g_slice_new0 (BackEntry);
 	entry->stack_page = g_strdup (gtk_stack_get_visible_child_name (GTK_STACK (priv->stack)));
 	entry->title = g_strdup (gtk_window_get_title (GTK_WINDOW (dialog)));
+	entry->focus = g_object_ref (gtk_window_get_focus (GTK_WINDOW (dialog)));
 
-	entry->focus = gtk_window_get_focus (GTK_WINDOW (dialog));
-	if (entry->focus != NULL)
-		g_object_add_weak_pointer (G_OBJECT (entry->focus),
-		                           (gpointer *) &entry->focus);
+	focus = gtk_window_get_focus (GTK_WINDOW (dialog));
+	if (focus != NULL)
+		entry->focus = g_object_ref (focus);
 
 	g_queue_push_head (priv->back_entry_stack, entry);
 }
@@ -78,8 +79,7 @@ static void
 back_entry_free (BackEntry *entry)
 {
 	if (entry->focus != NULL)
-		g_object_remove_weak_pointer (G_OBJECT (entry->focus),
-		                              (gpointer *) &entry->focus);
+		g_object_unref (entry->focus);
 	g_free (entry->stack_page);
 	g_free (entry->title);
 	g_slice_free (BackEntry, entry);
@@ -203,17 +203,6 @@ gs_update_dialog_show_installed_updates (GsUpdateDialog *dialog, GList *installe
 	}
 }
 
-static void
-unset_focus (GtkWidget *widget)
-{
-	GtkWidget *focus;
-
-	focus = gtk_window_get_focus (GTK_WINDOW (widget));
-	if (GTK_IS_LABEL (focus))
-		gtk_label_select_region (GTK_LABEL (focus), 0, 0);
-	gtk_window_set_focus (GTK_WINDOW (widget), NULL);
-}
-
 void
 gs_update_dialog_show_update_details (GsUpdateDialog *dialog, GsApp *app)
 {
@@ -227,10 +216,6 @@ gs_update_dialog_show_update_details (GsUpdateDialog *dialog, GsApp *app)
 	/* set update header */
 	set_updates_description_ui (dialog, app);
 
-	/* workaround a gtk+ issue where the dialog comes up with a label selected,
-	 * https://bugzilla.gnome.org/show_bug.cgi?id=734033 */
-	unset_focus (GTK_WIDGET (dialog));
-
 	/* set update description */
 	if (kind == GS_APP_KIND_OS_UPDATE) {
 		GPtrArray *related;
@@ -340,6 +325,17 @@ scrollbar_mapped_cb (GtkWidget *sb, GtkScrolledWindow *swin)
 	}
 }
 
+static void
+unset_focus (GtkWidget *widget)
+{
+	GtkWidget *focus;
+
+	focus = gtk_window_get_focus (GTK_WINDOW (widget));
+	if (GTK_IS_LABEL (focus))
+		gtk_label_select_region (GTK_LABEL (focus), 0, 0);
+	gtk_window_set_focus (GTK_WINDOW (widget), NULL);
+}
+
 static void
 gs_update_dialog_finalize (GObject *object)
 {
