@@ -35,7 +35,6 @@
 
 struct GsPluginPrivate {
 	AsStore			*store;
-	GMutex			 store_mutex;
 	gchar			*locale;
 	gsize			 done_init;
 	gboolean		 has_hi_dpi_support;
@@ -92,7 +91,6 @@ void
 gs_plugin_initialize (GsPlugin *plugin)
 {
 	plugin->priv = GS_PLUGIN_GET_PRIVATE (GsPluginPrivate);
-	g_mutex_init (&plugin->priv->store_mutex);
 	plugin->priv->store = as_store_new ();
 	g_signal_connect (plugin->priv->store, "changed",
 			  G_CALLBACK (gs_plugin_appstream_store_changed_cb),
@@ -125,10 +123,8 @@ gs_plugin_destroy (GsPlugin *plugin)
 {
 	g_free (plugin->priv->locale);
 	g_object_unref (plugin->priv->store);
-	g_mutex_clear (&plugin->priv->store_mutex);
 }
 
-#if AS_CHECK_VERSION(0,3,2)
 /**
  * gs_plugin_appstream_get_origins_hash:
  *
@@ -176,7 +172,6 @@ gs_plugin_appstream_get_origins_hash (GPtrArray *array)
 	g_list_free (keys);
 	return origins;
 }
-#endif
 
 /**
  * gs_plugin_startup:
@@ -184,20 +179,16 @@ gs_plugin_appstream_get_origins_hash (GPtrArray *array)
 static gboolean
 gs_plugin_startup (GsPlugin *plugin, GError **error)
 {
+	AsApp *app;
+	GHashTable *origins = NULL;
 	GPtrArray *items;
 	gboolean ret;
+	const gchar *origin;
 	gchar *tmp;
+	guint *perc;
 #if AS_CHECK_VERSION(0,3,1)
 	guint i;
 #endif
-#if AS_CHECK_VERSION(0,3,2)
-	AsApp *app;
-	GHashTable *origins = NULL;
-	const gchar *origin;
-	guint *perc;
-#endif
-
-	g_mutex_lock (&plugin->priv->store_mutex);
 
 	/* clear all existing applications if the store was invalidated */
 	as_store_remove_all (plugin->priv->store);
@@ -236,7 +227,6 @@ gs_plugin_startup (GsPlugin *plugin, GError **error)
 	}
 
 	/* add search terms for apps not in the main source */
-#if AS_CHECK_VERSION(0,3,2)
 	origins = gs_plugin_appstream_get_origins_hash (items);
 	for (i = 0; i < items->len; i++) {
 		app = g_ptr_array_index (items, i);
@@ -250,7 +240,6 @@ gs_plugin_startup (GsPlugin *plugin, GError **error)
 			as_app_add_keyword (app, NULL, origin, -1);
 		}
 	}
-#endif
 
 	/* look for any application with a HiDPI icon kudo */
 #if AS_CHECK_VERSION(0,3,1)
@@ -263,11 +252,8 @@ gs_plugin_startup (GsPlugin *plugin, GError **error)
 	}
 #endif
 out:
-#if AS_CHECK_VERSION(0,3,2)
 	if (origins != NULL)
 		g_hash_table_unref (origins);
-#endif
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::startup");
 	return ret;
 }
@@ -851,8 +837,6 @@ gs_plugin_refine_from_id (GsPlugin *plugin,
 	gboolean ret = TRUE;
 	AsApp *item = NULL;
 
-	g_mutex_lock (&plugin->priv->store_mutex);
-
 	/* find anything that matches the ID */
 	id = gs_app_get_id (app);
 	if (id == NULL)
@@ -866,7 +850,6 @@ gs_plugin_refine_from_id (GsPlugin *plugin,
 	if (!ret)
 		goto out;
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	*found = (item != NULL);
 	return ret;
 }
@@ -885,8 +868,6 @@ gs_plugin_refine_from_pkgname (GsPlugin *plugin,
 	gboolean ret = TRUE;
 	guint i;
 
-	g_mutex_lock (&plugin->priv->store_mutex);
-
 	/* find anything that matches the ID */
 	sources = gs_app_get_sources (app);
 	for (i = 0; i < sources->len && item == NULL; i++) {
@@ -906,7 +887,6 @@ gs_plugin_refine_from_pkgname (GsPlugin *plugin,
 	if (!ret)
 		goto out;
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	return ret;
 }
 
@@ -930,7 +910,7 @@ gs_plugin_refine (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	gs_profile_start (plugin->profile, "appstream::refine");
@@ -977,12 +957,11 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	/* get the two search terms */
 	gs_profile_start (plugin->profile, "appstream::add-category-apps");
-	g_mutex_lock (&plugin->priv->store_mutex);
 	search_id1 = gs_category_get_id (category);
 	parent = gs_category_get_parent (category);
 	if (parent != NULL)
@@ -1014,7 +993,6 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 		g_object_unref (app);
 	}
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::add-category-apps");
 	return ret;
 }
@@ -1116,12 +1094,11 @@ gs_plugin_add_search (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	/* search categories for the search term */
 	gs_profile_start (plugin->profile, "appstream::search");
-	g_mutex_lock (&plugin->priv->store_mutex);
 	array = as_store_get_apps (plugin->priv->store);
 	for (i = 0; i < array->len; i++) {
 		if (g_cancellable_set_error_if_cancelled (cancellable, error))
@@ -1133,7 +1110,6 @@ gs_plugin_add_search (GsPlugin *plugin,
 			goto out;
 	}
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::search");
 	return ret;
 }
@@ -1158,12 +1134,11 @@ gs_plugin_add_installed (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	/* search categories for the search term */
 	gs_profile_start (plugin->profile, "appstream::add_installed");
-	g_mutex_lock (&plugin->priv->store_mutex);
 	array = as_store_get_apps (plugin->priv->store);
 	for (i = 0; i < array->len; i++) {
 		item = g_ptr_array_index (array, i);
@@ -1177,7 +1152,6 @@ gs_plugin_add_installed (GsPlugin *plugin,
 		}
 	}
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::add_installed");
 	return ret;
 }
@@ -1247,12 +1221,11 @@ gs_plugin_add_categories (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	/* find out how many packages are in each category */
 	gs_profile_start (plugin->profile, "appstream::add-categories");
-	g_mutex_lock (&plugin->priv->store_mutex);
 	array = as_store_get_apps (plugin->priv->store);
 	for (i = 0; i < array->len; i++) {
 		app = g_ptr_array_index (array, i);
@@ -1262,7 +1235,7 @@ gs_plugin_add_categories (GsPlugin *plugin,
 			continue;
 		gs_plugin_add_categories_for_app (*list, app);
 	}
-	g_mutex_unlock (&plugin->priv->store_mutex);
+out:
 	gs_profile_stop (plugin->profile, "appstream::add-categories");
 	return ret;
 }
@@ -1523,10 +1496,9 @@ gs_plugin_add_popular (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 	gs_profile_start (plugin->profile, "appstream::add_popular");
-	g_mutex_lock (&plugin->priv->store_mutex);
 
 	/* get already installed applications */
 	ignore_apps = g_hash_table_new (g_str_hash, g_str_equal);
@@ -1567,7 +1539,6 @@ gs_plugin_add_popular (GsPlugin *plugin,
 	}
 
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::add_popular");
 	if (ignore_apps != NULL)
 		g_hash_table_unref (ignore_apps);
